summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings2/nsdata.cpp
authorwimpie <wimpie>2005-01-11 21:42:31 (UTC)
committer wimpie <wimpie>2005-01-11 21:42:31 (UTC)
commit96678694f8952f60d0a895cede2b621404b4bfb8 (patch) (side-by-side diff)
tree7138e554e5ba200b8f9ca8b51c89b47531dc34f2 /noncore/settings/networksettings2/nsdata.cpp
parentf89120a7a1a3d0bf9c0805456490906ca914e560 (diff)
downloadopie-96678694f8952f60d0a895cede2b621404b4bfb8.zip
opie-96678694f8952f60d0a895cede2b621404b4bfb8.tar.gz
opie-96678694f8952f60d0a895cede2b621404b4bfb8.tar.bz2
Major rename of NodeCollection to NetworkSetup
this commit is broken (missing symbols)
Diffstat (limited to 'noncore/settings/networksettings2/nsdata.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/settings/networksettings2/nsdata.cpp108
1 files changed, 54 insertions, 54 deletions
diff --git a/noncore/settings/networksettings2/nsdata.cpp b/noncore/settings/networksettings2/nsdata.cpp
index 39031ed..b4622fc 100644
--- a/noncore/settings/networksettings2/nsdata.cpp
+++ b/noncore/settings/networksettings2/nsdata.cpp
@@ -52,3 +52,3 @@ NetworkSettingsData::NetworkSettingsData( void ) {
if( F->open( IO_ReadOnly ) ) {
- NodeCollection * NC;
+ NetworkSetup * NC;
interfacename = TS.readLine();
@@ -59,3 +59,3 @@ NetworkSettingsData::NetworkSettingsData( void ) {
- NC = NSResources->getConnection( profilenr );
+ NC = NSResources->getNetworkSetup( profilenr );
if( NC ) {
@@ -101,3 +101,3 @@ void NetworkSettingsData::loadSettings( void ) {
<EMPTYLINE>
- [connection]
+ [NetworkSetup]
Name=Name
@@ -118,7 +118,7 @@ void NetworkSettingsData::loadSettings( void ) {
- if( S == "connection" ) {
- // load connections -> collections of nodes
+ if( S == "NetworkSetup" ) {
+ // load NetworkSetups -> collections of nodes
bool Dangling;
- NodeCollection * NC = new NodeCollection( TS, Dangling );
- NSResources->addConnection( NC, Dangling );
+ NetworkSetup * NC = new NetworkSetup( TS, Dangling );
+ NSResources->addNetworkSetup( NC, Dangling );
} else {
@@ -253,10 +253,10 @@ QString NetworkSettingsData::saveSettings( void ) {
- // good connections
- { Name2Connection_t & M = NSResources->connections();
+ // good NetworkSetups
+ { Name2NetworkSetup_t & M = NSResources->networkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
- TS << "[connection]" << endl;
+ TS << "[NetworkSetup]" << endl;
it.current()->save(TS);
@@ -265,10 +265,10 @@ QString NetworkSettingsData::saveSettings( void ) {
- // save dangling connections
- { Name2Connection_t & M = NSResources->danglingConnections();
+ // save dangling NetworkSetups
+ { Name2NetworkSetup_t & M = NSResources->danglingNetworkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
++it ) {
- TS << "[connection]" << endl;
+ TS << "[NetworkSetup]" << endl;
it.current()->save(TS);
@@ -285,3 +285,3 @@ QString NetworkSettingsData::saveSettings( void ) {
- for( QDictIterator<NodeCollection> it(NSResources->connections());
+ for( QDictIterator<NetworkSetup> it(NSResources->networkSetups());
it.current();
@@ -297,4 +297,4 @@ QString NetworkSettingsData::generateSettings( void ) {
Name2SystemFile_t & SFM = NSResources->systemFiles();
- Name2Connection_t & M = NSResources->connections();
- NodeCollection * NC;
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
+ NetworkSetup * NC;
ANetNodeInstance * NNI;
@@ -430,3 +430,3 @@ QString NetworkSettingsData::generateSettings( void ) {
- for( QDictIterator<NodeCollection> ncit(M);
+ for( QDictIterator<NetworkSetup> ncit(M);
ncit.current();
@@ -490,4 +490,4 @@ QString NetworkSettingsData::generateSettings( void ) {
- // find connections that want to write to this file
- for( QDictIterator<NodeCollection> ncit(M);
+ // find NetworkSetups that want to write to this file
+ for( QDictIterator<NetworkSetup> ncit(M);
ncit.current();
@@ -507,3 +507,3 @@ QString NetworkSettingsData::generateSettings( void ) {
- Log(("Generating %s for connection %s\n",
+ Log(("Generating %s for NetworkSetup %s\n",
SF->name().latin1(), NC->name().latin1() ));
@@ -512,3 +512,3 @@ QString NetworkSettingsData::generateSettings( void ) {
// find device on which this connection works
CurDev = NC->device();
@@ -573,4 +573,4 @@ QString NetworkSettingsData::generateSettings( void ) {
// generate profile specific info
- // for all nodeconnections that work on the same device
- for( QDictIterator<NodeCollection> ncit2(M);
+ // for all nodeNetworkSetups that work on the same device
+ for( QDictIterator<NetworkSetup> ncit2(M);
ncit2.current();
@@ -583,3 +583,3 @@ QString NetworkSettingsData::generateSettings( void ) {
- Log(("Connection %s of family %s\n",
+ Log(("NetworkSetup %s of family %s\n",
ncit2.current()->name().latin1(),
@@ -647,11 +647,11 @@ QString NetworkSettingsData::generateSettings( void ) {
-QList<NodeCollection> NetworkSettingsData::collectPossible(
+QList<NetworkSetup> NetworkSettingsData::collectPossible(
const QString & Interface ) {
- // collect connections that can work on top of this interface
- NodeCollection * NC;
- QList<NodeCollection> PossibleConnections;
- Name2Connection_t & M = NSResources->connections();
+ // collect NetworkSetups that can work on top of this interface
+ NetworkSetup * NC;
+ QList<NetworkSetup> PossibleNetworkSetups;
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
- // for all connections
- for( QDictIterator<NodeCollection> it(M);
+ // for all NetworkSetups
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
@@ -666,6 +666,6 @@ QList<NodeCollection> NetworkSettingsData::collectPossible(
NC->name().latin1(), Interface.latin1() ));
- PossibleConnections.append( NC );
+ PossibleNetworkSetups.append( NC );
}
}
- return PossibleConnections;
+ return PossibleNetworkSetups;
}
@@ -681,14 +681,14 @@ bool NetworkSettingsData::canStart( const QString & Interface ) {
// load situation
- NodeCollection * NC = 0;
- QList<NodeCollection> PossibleConnections;
+ NetworkSetup * NC = 0;
+ QList<NetworkSetup> PossibleNetworkSetups;
- PossibleConnections = collectPossible( Interface );
+ PossibleNetworkSetups = collectPossible( Interface );
Log( ( "for %s : Possiblilies %d\n",
- Interface.latin1(), PossibleConnections.count() ));
- switch( PossibleConnections.count() ) {
- case 0 : // no connections
+ Interface.latin1(), PossibleNetworkSetups.count() ));
+ switch( PossibleNetworkSetups.count() ) {
+ case 0 : // no NetworkSetups
break;
- case 1 : // one connection
- NC = PossibleConnections.first();
+ case 1 : // one NetworkSetup
+ NC = PossibleNetworkSetups.first();
break;
@@ -738,3 +738,3 @@ bool NetworkSettingsData::isModified( void ) {
- for( QDictIterator<NodeCollection> it(NSResources->connections());
+ for( QDictIterator<NetworkSetup> it(NSResources->networkSetups());
it.current();
@@ -750,3 +750,3 @@ bool NetworkSettingsData::couldBeTriggered( const QString & Interface ) {
// load situation
- QList<NodeCollection> PossibleTriggered;
+ QList<NetworkSetup> PossibleTriggered;
@@ -760,13 +760,13 @@ bool NetworkSettingsData::couldBeTriggered( const QString & Interface ) {
-QList<NodeCollection> NetworkSettingsData::collectTriggered(
+QList<NetworkSetup> NetworkSettingsData::collectTriggered(
const QString & Interface ) {
- // collect connections that could be triggered by this interface
- NodeCollection * NC;
- QList<NodeCollection> PossibleTriggered;
+ // collect NetworkSetups that could be triggered by this interface
+ NetworkSetup * NC;
+ QList<NetworkSetup> PossibleTriggered;
- // for all connections
- Name2Connection_t & M = NSResources->connections();
+ // for all NetworkSetups
+ Name2NetworkSetup_t & M = NSResources->networkSetups();
- for( QDictIterator<NodeCollection> it(M);
+ for( QDictIterator<NetworkSetup> it(M);
it.current();
@@ -512,3 +512,3 @@ QString NetworkSettingsData::generateSettings( void ) {
SF->name().latin1(), NC->name().latin1() ));
- // find device on which this connection works
+ // find device on which this NetworkSetup works
CurDev = NC->device();